<?php
/**
* Plugin Name: Knjižnice: Vtičnik dogodki
* Plugin URI: https://www.knjiznice.si
* Description: Urejanje in prikazovanje dogodkov na spletni strani.
* Version: 1.2.2
* Author: TrueCAD d.o.o.
* Author URI: https://www.truecad.si/
**/

/** CUSTOM TYPE */
function knjiznice_register_posttype_dogodki() {
	
	$labels = array(
		'name' => __('Kategorije dogodkov', 'knjiznice'),
		'singular_name' => __('Kategorija', 'knjiznice'),
		'search_items' =>  __( 'Išči kategorijo', 'knjiznice'),
		'all_items' => __( 'Vse kategorije', 'knjiznice'),
		'parent_item' => __( 'Nadrejena kategorija', 'knjiznice'),
		'parent_item_colon' => __( 'Nadrejena kategorija:', 'knjiznice'),
		'edit_item' => __( 'Uredi kategorijo', 'knjiznice'), 
		'update_item' => __( 'Posodobi kategorijo', 'knjiznice'),
		'add_new_item' => __( 'Dodaj novo', 'knjiznice'),
		'new_item_name' => __( 'Novo ime', 'knjiznice'),
		'menu_name' => __( 'Kategorije', 'knjiznice'),
	);    
 
	register_taxonomy('kategorije-dogodki', array('dogodki'), array(
		'hierarchical' => true,
		'labels' => $labels,
		'show_ui' => true,
		'show_admin_column' => true,
		'query_var' => true,
		'rewrite' => array( 'slug' => 'kategorija-dogodka' )
	));
	
	$supports = array(
		'title', // post title
		'editor', // post content
		'author', // post author
		'thumbnail', // featured images
		'revisions', // post revisions
		'post-formats', // post formats
		'comments' // comments
	);
	
	$labels = array(
		'name' => __('Dogodki', 'knjiznice'),
        'singular_name' => __('Dogodek', 'knjiznice'),
		'menu_name' => __('Dogodki', 'knjiznice'),
		'name_admin_bar' => __('Dogodki', 'knjiznice'),
		'add_new' => __('Dodaj nov', 'knjiznice'),
		'add_new_item' => __('Dodaj nov dogodek', 'knjiznice'),
		'new_item' => __('Nov dogodek', 'knjiznice'),
		'edit_item' => __('Uredi dogodek', 'knjiznice'),
		'view_item' => __('Poglej dogodek', 'knjiznice'),
		'all_items' => __('Vsi dogodki', 'knjiznice'),
		'search_items' => __('Iskanje dogodkov', 'knjiznice'),
		'not_found' => __('Ni dogodkov.', 'knjiznice')
	);
	
    register_post_type( 'dogodki',
        array(
			'supports' => $supports,
            'labels' => $labels,
            'public' => true,
            'has_archive' => true,
			'taxonomies' 	      => array('kategorije-dogodki'),
            'rewrite' => array('slug' => 'dogodki'),
        )
    );
}
add_action( 'init', 'knjiznice_register_posttype_dogodki' );

/** ORDER */

function knjiznice_order_posttype_dogodki($query) {
   if ($query->is_main_query() && $query->is_post_type_archive('dogodki') && !is_admin()) {
       $query->set('orderby', 'meta_value_num');
       $query->set('meta_key', 'dogodek_zacetek_datum');
       $query->set('order', 'ASC');
	   $location = !empty($_GET['location']) ? $_GET['location']:false;
	   $for = !empty($_GET['for']) ? $_GET['for']:false;
	   if (!empty($_GET['date'])) {
		$query->set('meta_query', array(
			array(
				'key' => 'dogodek_zacetek_datum',
				'value' => str_replace('-', '', $_GET['date']),
				'compare' => '='
			)
		));
	   } else if ($location !== false) {
			$query->set('meta_query', array(
				'relation' => 'AND',
				array(
					'relation' => 'OR',
					array(
						'key' => 'dogodek_zacetek_datum',
						'value' => date("Ymd"),
						'compare' => '>='
					),
					array(
						'key' => 'dogodek_konec_datum',
						'value' => date("Ymd"),
						'compare' => '>='
					)
				),
				array(
					'key' => 'dogodek_lokacija',
					'value' => $location,
					'compare' => '='
				)
			));
		} else if ($for !== false) {
			$query->set('meta_query', array(
				'relation' => 'AND',
				array(
					'relation' => 'OR',
					array(
						'key' => 'dogodek_zacetek_datum',
						'value' => date("Ymd"),
						'compare' => '>='
					),
					array(
						'key' => 'dogodek_konec_datum',
						'value' => date("Ymd"),
						'compare' => '>='
					)
				),
				array(
					'key' => 'dogodek_namenjeno',
					'value' => $for,
					'compare' => 'LIKE'
				)
			));
	   } else {
		    $query->set('meta_query', array(
				'relation' => 'OR',
				array(
					'key' => 'dogodek_zacetek_datum',
					'value' => date("Ymd"),
					'compare' => '>='
				),
				array(
					'key' => 'dogodek_konec_datum',
					'value' => date("Ymd"),
					'compare' => '>='
				)
			));
	   }
	   
	   /*$query->set('orderby', 'meta_value_num');
       $query->set('meta_key', '_liked');
       $query->set('order', 'DESC');*/
   }
}
add_action( 'pre_get_posts', 'knjiznice_order_posttype_dogodki' );

/**WIDGET */

class knjiznice_widget_koledardogodkov extends WP_Widget {
	function __construct() {
		parent::__construct('knjiznice_widget_koledardogodkov', __('Koledar dogodkov', 'knjiznice'), array( 'description' => __( 'Koledar dogodkov knjižnice', 'knjiznice' )));
	}
	
	public function widget( $args, $instance ) {
		$title = apply_filters('widget_title', $instance['title']);
		echo $args['before_widget'];
		if ( ! empty( $title ) )
		echo $args['before_title'] . $title . $args['after_title'];
		$current_month = date("m");
		$current_year = date("Y");
		if (!empty($_GET['date'])) {
			$current_month = date("m", strtotime($_GET['date']));
			$current_year = date("Y", strtotime($_GET['date'])); 
		}
		$query_args = array(
			'post_type' => array('dogodki'),
			'post_status' => array('publish'),
			'posts_per_page' => '1000',
			'meta_query' => array(
				array(
					'key' => 'dogodek_zacetek_datum',
					'value' => (intval(date("Ymd"))-365),
					'compare' => '>='
				)
			)
		);
		$dogodki = array();
		$query_dogodek = new WP_Query($query_args);
		while ($query_dogodek->have_posts()) {
			$query_dogodek->the_post();
			$dogodek = new stdClass; 
			$dogodek->title = get_the_title();
			$dogodek->date = date("Y-m-d",	strtotime(get_field("dogodek_zacetek")["datum"])); 
			$dogodek->badge = false;
			$dogodki[] = $dogodek;
		}
		wp_reset_postdata();
		//echo json_encode($dogodki);
		?>
		<script type="text/javascript">
			jQuery(document).ready(function() {
				jQuery("#knjiznice-widget-dogodki-calendar").zabuto_calendar({
					"language": "sl",
					"weekstartson": 1,
					"today":true,
					"month":"<?php echo $current_month; ?>",
					"year":"<?php echo $current_year; ?>",
					"data": <?php echo json_encode($dogodki) ?>,
					"action":knjiznicewidgeteventclick
				});
			});
			function knjiznicewidgeteventclick() {
				var date = jQuery("#" + this.id).data("date");
				if (jQuery("#" + this.id).data("hasEvent")) {
					window.location.href = '<?php echo get_post_type_archive_link("dogodki"); ?>?date='+date;
				}
			}
		</script>
		
		<div id="knjiznice-widget-dogodki-calendar"></div>
		<?php
		echo $args['after_widget'];
	}
	
	public function form($instance) {
		$title = '';
		if (isset($instance['title'])) $title = $instance['title'];
		else $title = __('', 'knjiznice');
		?>
		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label> 
			<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
		</p>
		<?php 
	}
	
	public function update($new_instance, $old_instance) {
		$instance = array();
		$instance['title'] = (!empty($new_instance['title'])) ? strip_tags($new_instance['title']) : '';
		return $instance;
	}
}

class knjiznice_widget_kategorijedogodkov extends WP_Widget {
	function __construct() {
		parent::__construct('knjiznice_widget_kategorijedogodkov', __('Kategorije dogodkov', 'knjiznice'), array( 'description' => __( 'Kategorije dogodkov knjižnice', 'knjiznice' )));
	}
	
	public function widget( $args, $instance ) {
		$title = apply_filters('widget_title', $instance['title']);
		echo $args['before_widget'];
		if ( ! empty( $title ) )
		echo $args['before_title'] . $title . $args['after_title'];
		$categories_dogodki = get_terms(array('taxonomy' => 'kategorije-dogodki','hide_empty' => false));
		$current_obj = get_queried_object();
		$term_id = -1;
		if ($current_obj instanceof WP_Term) $term_id = $current_obj->term_id;
		?>
		<ul>
			<?php foreach ($categories_dogodki as $category_dogodki) : ?>
			<li class="<?php echo $term_id == $category_dogodki->term_id ? 'current':''; ?>"><a href="<?php echo get_term_link($category_dogodki); ?>"><?php echo $category_dogodki->name; ?> (<?php echo $category_dogodki->count; ?>)</a></li>
			<?php endforeach; ?>
		</ul>
		<?php
		echo $args['after_widget'];
	}
	
	public function form($instance) {
		$title = '';
		if (isset($instance['title'])) $title = $instance['title'];
		else $title = __('', 'knjiznice');
		?>
		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label> 
			<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
		</p>
		<?php 
	}
	
	public function update($new_instance, $old_instance) {
		$instance = array();
		$instance['title'] = (!empty($new_instance['title'])) ? strip_tags($new_instance['title']) : '';
		return $instance;
	}
}

class knjiznice_widget_prihajajocidogodki_home extends WP_Widget {		
	function __construct() {
		parent::__construct(
			'knjiznice_widget_prihajajocidogodki_home', 
			__('Prihajajoči dogodki - Prva stran', 'knjiznice'), 
			array( 'description' => __( 'Prikaz prihajajočih dogodkov na prvi strani', 'knjiznice' ))
			);
	}
	public function widget( $args, $instance ) {
		setlocale(LC_TIME, get_locale());
		$query_args = array(
			'post_type' => array('dogodki'),
			'post_status' => array('publish'),
			'posts_per_page' => 4,
			'orderby' => 'meta_value_num',
			'meta_key' => 'dogodek_zacetek_datum',
			'order' => 'ASC',
			'meta_query' => array(
				/*'relation' => 'OR',*/
				array(
					'key' => 'dogodek_zacetek_datum',
					'value' => date("Ymd"),
					'compare' => '>='
				)/*,
				array(
					'key' => 'dogodek_konec_datum',
					'value' => date("Ymd"),
					'compare' => '>='
				)*/
			)
		);
		$query_dogodek = new WP_Query($query_args);
		?>
		<div id="dogodki-home" class="row" style="padding: 50px 0">
		<?php
		if($query_dogodek->have_posts()) {
			while($query_dogodek->have_posts()) {
				$query_dogodek->the_post();
				?>
				<div class="row col-12 dogodek">
					<div class="entry-meta col-lg-2">
						<div class="entry-meta-inner">
							<div class="entry-meta-date">
							<?php if (get_field("dogodek_konec")): ?>
								<?php echo date("d", strtotime(get_field("dogodek_zacetek")["datum"])); ?>-<?php echo date("d", strtotime(get_field("dogodek_konec")["datum"])); ?>
							<?php else: ?>
								<?php echo date("d", strtotime(get_field("dogodek_zacetek")["datum"])); ?>	
							<?php endif; ?>
							</div>
							<div class="entry-meta-date-small">
								<?php echo strftime("%b", strtotime(get_field("dogodek_zacetek")["datum"])); ?>
								<?php if (get_field("dogodek_vecdnevni")): ?>
									- <?php echo strftime("%b", strtotime(get_field("dogodek_konec")["datum"])); ?>
								<?php endif; ?>
							</div>
						</div>
					</div>
					<div class="post-content <?php echo has_post_thumbnail() ? "col-lg-7":"col-lg-10"?>">
						<a href="<?php the_permalink(); ?>"><h3 class="entry-title"><?php the_title();?></h3></a>
						<p class="post-excerpt"><?php echo wp_trim_words( get_the_excerpt(), 30, " ..." );?></p>
					</div>
					<?php if (has_post_thumbnail()): ?>
					<div class="entry-image col-lg-3">
						<?php knjiznice_post_thumbnail('post-thumbnail'); ?>
					</div>
					<?php endif; ?>
				</div>
				<?php
			} 
			wp_reset_postdata();
		}
		?>
		</div>
		<?php
		}
		
		public function update($new_instance, $old_instance) {
			$instance = array();
			$instance['title'] = (!empty($new_instance['title'])) ? strip_tags($new_instance['title']) : '';
			return $instance;
		}	
}
class knjiznice_widget_prihajajocidogodki extends WP_Widget {
	function __construct() {
		parent::__construct('knjiznice_widget_prihajajocidogodki', __('Prihajajoči dogodki', 'knjiznice'), array( 'description' => __( 'KPrihajajoči dogodki knjižnice', 'knjiznice' )));
	}
	
	public function widget( $args, $instance ) {
		$title = apply_filters('widget_title', $instance['title']);
		echo $args['before_widget'];
		if ( ! empty( $title ) )
		echo $args['before_title'] . $title . $args['after_title'];
		$query_args = array(
			'post_type' => array('dogodki'),
			'post_status' => array('publish'),
			'posts_per_page' => $instance['stevilodogodkov'],
			'orderby' => 'meta_value_num',
			'meta_key' => 'dogodek_zacetek_datum',
			'order' => 'ASC',
			'meta_query' => array(
				array(
					'key' => 'dogodek_zacetek_datum',
					'value' => (intval(date("Ymd"))),
					'compare' => '>='
				)
			)
		);
		$dogodki = array();
		$query_dogodek = new WP_Query($query_args);
		
		?>
		<div id="knjiznice-widget-prihajajoci">
			<?php if ($query_dogodek->have_posts()): ?>
				<ul>
				<?php while ($query_dogodek->have_posts()): ?>
					<?php $query_dogodek->the_post(); ?>
					<li><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></li>
				<?php endwhile; ?>
				</ul>
			<?php else: ?>
				<p>Ni dogodkov</p>
			<?php endif; ?>
		</div>
		<?php
		wp_reset_postdata();
		echo $args['after_widget'];
	}
	
	public function form($instance) {
		$title = '';
		$stevilodogodkov = '';
		if (isset($instance['title'])) $title = $instance['title'];
		else $title = __('', 'knjiznice');
		if (isset($instance['stevilodogodkov'])) $stevilodogodkov = $instance['stevilodogodkov'];
		
		?>
		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label> 
			<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('stevilodogodkov'); ?>"><?php _e('Stevilo dogodkov:'); ?></label> 
			<input class="tiny-text" id="<?php echo $this->get_field_id('stevilodogodkov'); ?>" name="<?php echo $this->get_field_name('stevilodogodkov'); ?>" type="number" step="1" min="1" value="<?php echo esc_attr($stevilodogodkov); ?>" size="3">
		</p>
		<?php 
	}
	
	public function update($new_instance, $old_instance) {
		$instance = array();
		$instance['title'] = (!empty($new_instance['title'])) ? strip_tags($new_instance['title']) : '';
		$instance['stevilodogodkov'] = (!empty($new_instance['stevilodogodkov'])) ? strip_tags($new_instance['stevilodogodkov']) : '';
		return $instance;
	}
}

class knjiznice_widget_lokacijadogodki extends WP_Widget {
	function __construct() {
		parent::__construct('knjiznice_widget_lokacijadogodki', __('Filter lokacije dogodkov', 'knjiznice'), array( 'description' => __( 'Filter lokacije dogodkov', 'knjiznice' )));
	}
	
	public function widget( $args, $instance ) {
		global $wp;
		$title = apply_filters('widget_title', $instance['title']);
		echo $args['before_widget'];
		if (!empty($title))
			echo $args['before_title'] . $title . $args['after_title'];
		
		$field = get_field_object('dogodek_lokacija');
		$choices = $field['choices'];
		?>
		<div id="knjiznice-widget-lokacija">
			<ul>
				<?php foreach( $choices as $choice => $label ) : ?>
				<li><a href="<?php echo home_url($wp->request); ?>?location=<?php echo $choice; ?>"><?php echo $label; ?></a></li>
				<?php endforeach; ?>
			</ul>
		</div>
		<?php
		echo $args['after_widget'];
	}
	
	public function form($instance) {
		$title = '';
		$stevilodogodkov = '';
		if (isset($instance['title'])) $title = $instance['title'];
		else $title = __('', 'knjiznice');
		if (isset($instance['stevilodogodkov'])) $stevilodogodkov = $instance['stevilodogodkov'];
		
		?>
		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label> 
			<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
		</p>
		<?php 
	}
	
	public function update($new_instance, $old_instance) {
		$instance = array();
		$instance['title'] = (!empty($new_instance['title'])) ? strip_tags($new_instance['title']) : '';
		return $instance;
	}
}

class knjiznice_widget_namenjendogodek extends WP_Widget {
	function __construct() {
		parent::__construct('knjiznice_widget_namenjendogodek', __('Filter namenjen dogodek', 'knjiznice'), array( 'description' => __( 'Filter namenjen dogodek', 'knjiznice' )));
	}
	
	public function widget( $args, $instance ) {
		global $wp;
		$title = apply_filters('widget_title', $instance['title']);
		echo $args['before_widget'];
		if (!empty($title))
			echo $args['before_title'] . $title . $args['after_title'];
		
		$field = get_field_object('dogodek_namenjeno');
		$choices = $field['choices'];
		?>
		<div id="knjiznice-widget-namenjeno">
			<ul>
				<?php foreach( $choices as $choice => $label ) : ?>
				<li><a href="<?php echo home_url($wp->request); ?>?for=<?php echo $choice; ?>"><?php echo $label; ?></a></li>
				<?php endforeach; ?>
			</ul>
		</div>
		<?php
		echo $args['after_widget'];
	}
	
	public function form($instance) {
		$title = '';
		if (isset($instance['title'])) $title = $instance['title'];
		else $title = __('', 'knjiznice');
		
		?>
		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label> 
			<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
		</p>
		<?php 
	}
	
	public function update($new_instance, $old_instance) {
		$instance = array();
		$instance['title'] = (!empty($new_instance['title'])) ? strip_tags($new_instance['title']) : '';
		return $instance;
	}
}

function knjiznice_register_widgets_dogodki() {
	 register_widget('knjiznice_widget_koledardogodkov');
	 register_widget('knjiznice_widget_kategorijedogodkov');
	 register_widget('knjiznice_widget_prihajajocidogodki');
	 register_widget('knjiznice_widget_prihajajocidogodki_home');
	 register_widget('knjiznice_widget_lokacijadogodki');
	 register_widget('knjiznice_widget_namenjendogodek');
}
add_action('widgets_init', 'knjiznice_register_widgets_dogodki');

function knjiznice_dogodek_parent_active_menu($menu)
{
    global $post;
    if (get_post_type($post) == 'dogodki')
    {
        $menu = str_replace( 'menu-item-object-dogodki', 'current-menu-parent', $menu);
    }
    return $menu;
}
add_filter( 'nav_menu_css_class', 'knjiznice_dogodek_parent_active_menu', 10,2 );

function knjiznice_dogodki_add_scripts() {
	
	wp_enqueue_style( 'zabuto-calendar-css', plugin_dir_url(__FILE__) . '/css/zabuto-calendar.css', array(), '1.0');
	wp_enqueue_script( 'zabuto-calendar-js' , plugin_dir_url(__FILE__) . '/js/zabuto-calendar.js', array('jquery'), '1.0');
}
add_action( 'wp_enqueue_scripts', 'knjiznice_dogodki_add_scripts' );